exceptiontools.MissingMeasureError
==================================

.. inheritance-diagram:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
